==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Send");
define("_URL","URL");
define("_PRINTER","Printer Friendly Page");
define("_FRIEND","Send to a Friend");
define("_YOURNAME","Your Name");
define("_OK","Ok!");
define("_RELATED","Related Links");
define("_MOREABOUT","More about");
define("_NEWSBY","News by");
define("_MOSTREAD","Most read story about");
define("_READMORE","Read More...");
define("_BYTESMORE","bytes more");
define("_COMMENTSQ","comments?");
define("_COMMENT","comment");
define("_CONFIGURE","Configure");
define("_LOGINCREATE","Login/Create an Account");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","No Comments");
define("_NESTED","Nested");
define("_FLAT","Flat");
define("_THREAD","Thread");
define("_OLDEST","Oldest First");
define("_NEWEST","Newest First");
define("_HIGHEST","Highest Scores First");
define("_COMMENTSWARNING","The comments are owned by the poster. We aren't responsible for their content.");
define("_SCORE","Score:");
define("_USERINFO","User Info");
define("_READREST","Read the rest of this comment...");
define("_REPLY","Reply to This");
define("_REPLYMAIN","Post Comment");
define("_NOSUBJECT","No Subject");
define("_NOANONCOMMENTS","No Comments Allowed for Anonymous, please <a href=\"modules.php?name=Your_Account\">register</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Comment");
define("_ALLOWEDHTML","Allowed HTML:");
define("_POSTANON","Post Anonymously");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","HTML Formated");
define("_PLAINTEXT","Plain Old Text");
define("_ONN","on...");
define("_SUBJECT","Subject");
define("_COMMENTREPLY","Comment Post");
define("_COMREPLYPRE","Comment Post Preview");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_SENDAMSG","Send a Message");
define("_YOUSENDSTORY","You will send the story");
define("_TOAFRIEND","to a specified friend:");
define("_FYOURNAME","Your Name:");
define("_FYOUREMAIL","Your E-mail:");
define("_FFRIENDNAME","Your Friend's Name:");
define("_FFRIENDEMAIL","Your Friend's E-mail:");
define("_INTERESTING","Interesting Article at");
define("_HELLO","Hello");
define("_YOURFRIEND","Your Friend");
define("_CONSIDERED","considered the following article interesting and wanted to send it to you.");
define("_FDATE","Date:");
define("_FTOPIC","Topic:");
define("_YOUCANREAD","You can read interesting articles at");
define("_FSTORY","Story");
define("_HASSENT","Has been sent to");
define("_THANKS","Thanks!");
define("_RECOMMEND","Recommend this Site to a Friend");
define("_PDATE","Date:");
define("_PTOPIC","Topic:");
define("_COMESFROM","This article comes from");
define("_THEURL","The URL for this story is:");
define("_PREVIEW","Preview");
define("_NEWUSER","New User");
define("_OPTIONS","Options");
define("_REFRESH","Refresh");
define("_ADD","Add");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Send");
define("_URL","URL");
define("_PRINTER","Printer Friendly Page");
define("_FRIEND","Send to a Friend");
define("_YOURNAME","Your Name");
define("_OK","Ok!");
define("_RELATED","Related Links");
define("_MOREABOUT","More about");
define("_NEWSBY","News by");
define("_MOSTREAD","Most read story about");
define("_READMORE","Read More...");
define("_BYTESMORE","bytes more");
define("_COMMENTSQ","comments?");
define("_COMMENT","comment");
define("_CONFIGURE","Configure");
define("_LOGINCREATE","Login/Create an Account");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","No Comments");
define("_NESTED","Nested");
define("_FLAT","Flat");
define("_THREAD","Thread");
define("_OLDEST","Oldest First");
define("_NEWEST","Newest First");
define("_HIGHEST","Highest Scores First");
define("_COMMENTSWARNING","The comments are owned by the poster. We aren't responsible for their content.");
define("_SCORE","Score:");
define("_USERINFO","User Info");
define("_READREST","Read the rest of this comment...");
define("_REPLY","Reply to This");
define("_REPLYMAIN","Post Comment");
define("_NOSUBJECT","No Subject");
define("_NOANONCOMMENTS","No Comments Allowed for Anonymous, please <a href=\"modules.php?name=Your_Account\">register</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Comment");
define("_ALLOWEDHTML","Allowed HTML:");
define("_POSTANON","Post Anonymously");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","HTML Formated");
define("_PLAINTEXT","Plain Old Text");
define("_ONN","on...");
define("_SUBJECT","Subject");
define("_COMMENTREPLY","Comment Post");
define("_COMREPLYPRE","Comment Post Preview");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_SENDAMSG","Send a Message");
define("_YOUSENDSTORY","You will send the story");
define("_TOAFRIEND","to a specified friend:");
define("_FYOURNAME","Your Name:");
define("_FYOUREMAIL","Your E-mail:");
define("_FFRIENDNAME","Your Friend's Name:");
define("_FFRIENDEMAIL","Your Friend's E-mail:");
define("_INTERESTING","Interesting Article at");
define("_HELLO","Hello");
define("_YOURFRIEND","Your Friend");
define("_CONSIDERED","considered the following article interesting and wanted to send it to you.");
define("_FDATE","Date:");
define("_FTOPIC","Topic:");
define("_YOUCANREAD","You can read interesting articles at");
define("_FSTORY","Story");
define("_HASSENT","Has been sent to");
define("_THANKS","Thanks!");
define("_RECOMMEND","Recommend this Site to a Friend");
define("_PDATE","Date:");
define("_PTOPIC","Topic:");
define("_COMESFROM","This article comes from");
define("_THEURL","The URL for this story is:");
define("_PREVIEW","Preview");
define("_NEWUSER","New User");
define("_OPTIONS","Options");
define("_REFRESH","Refresh");
define("_ADD","Add");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
